@@ -87,9 +87,28 @@ class CoverageTest(
         The imported module is returned.
 
         """
-        with cov.collect():
+        # Here's something I don't understand. I tried changing the code to use
+        # the handy context manager, like this:
+        #
+        #   with cov.collect():
+        #       # Import the Python file, executing it.
+        #       return import_local_file(modname, modfile)
+        #
+        # That seemed to work, until 7.4.0 when it made metacov fail after
+        # running all the tests.  The deep recursion tests in test_oddball.py
+        # seemed to cause something to be off so that a "Trace function
+        # changed" error would happen as pytest was cleaning up, failing the
+        # metacov runs.  Putting back the old code below fixes it, but I don't
+        # understand the difference.
+
+        cov.start()
+        try:                                    # pragma: nested
             # Import the Python file, executing it.
-            return import_local_file(modname, modfile)
+            mod = import_local_file(modname, modfile)
+        finally:                                # pragma: nested
+            # Stop coverage.py.
+            cov.stop()
+        return mod
 
     def get_report(self, cov: Coverage, squeeze: bool = True, **kwargs: Any) -> str:
         """Get the report from `cov`, and canonicalize it."""
